Learn R Programming

gfmR (version 1.1-0)

predict.gfmR: Predict method for group fused multinomial logistic regression

Description

This routine fits the group fused multinomial logistic regression model, which uses fusion shrinkage to automatically combine response categories.

Usage

# S3 method for gfmR
predict(object,newdata,type="probs",...)

Arguments

object

A gfmr object which specifically is the output from the GroupFusedMulti function.

newdata

value to be predicted in model matrix form

type

Type of prediction, "probs" returns probabilities, while response returns log of the ratio of probabilities for baseline category

...

Other arguments

Value

A vector or a matrix corresponding to type return.

Details

Prediction function for GFMR

References

Price, B.S, Geyer, C.J. and Rothman, A.J. "Automatic Response Category Combination in Multinomial Logistic Regression." https://arxiv.org/abs/1705.03594.

Examples

Run this code
# NOT RUN {
# }
# NOT RUN {
data(nes96)
attach(nes96)
Response=matrix(0,944,7)
for(i in 1:944){
  if(PID[i]=="strRep"){Response[i,1]=1}
  if(PID[i]=="weakRep"){Response[i,2]=1}
  if(PID[i]=="indRep"){Response[i,3]=1}
  if(PID[i]=="indind"){Response[i,4]=1}
  if(PID[i]=="indDem"){Response[i,5]=1}
  if(PID[i]=="weakDem"){Response[i,6]=1}
  if(PID[i]=="strDem"){Response[i,7]=1}
}

Hmat=matrix(1,dim(Response)[2],dim(Response)[2])
diag(Hmat)=0
ModMat<-lm(popul~age,x=TRUE)$x

X=cbind(ModMat[,1],apply(ModMat[,-1],2,scale))
mod<-GroupFusedMulti(Response,X,lambda=2^4.3,H=Hmat2,rho=10^2,iter=50,tol1=10^-4,tol2=10^-4)
predict(mod,X[1,])
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab